@@ -343,13 +343,20 @@ class Run():
 
         if save_model == True:
             class_type = str(type(target))
+            import os
+            import time
+            epoch_time = int(time.time())
+            os.mkdir(str(epoch_time))
+            _path = str(epoch_time) + '/project'
+            os.mkdir(_path)
             if target == None:
                 print('no model specified, skipping')
                 pass
             else:
                 if 'keras' in class_type:
-                    print('Keras Model detected, saving to ./saved_model.pb')
-                    target.save('saved_model.pb')
+                    _save_path = _path + '/saved_model.pb'
+                    print('Keras Model detected, saving to ' + _save_path)
+                    target.save(_save_path)
                     pass
                 if 'tensorflow' in class_type and 'keras' not in class_type:
                     if target._closed:
@@ -357,20 +364,36 @@ class Run():
                             'session closed, please run conclude() function in session')
                         return
                     else:
-                        print('Tensorflow Model detected, saving to ./saved_model.pb')
+                        _save_path = _path + '/saved_model.pb'
+                        print('Tensorflow Model detected, saving to ' + _save_path)
                         import tensorflow as tf
                         saver = tf.train.Saver()
-                        saver.save(target, 'saved_model.pb')
+                        saver.save(target, _save_path)
                         pass
                 elif 'tensorflow' not in class_type and 'keras' not in class_type:
                     try:
-                        print('Torch Model detected, saving to ./saved_model.pth')
+                        _save_path = _path + '/saved_model.pth'
+                        print('Torch Model detected, saving to ' + _save_path)
                         import torch
-                        torch.save(target.state_dict(), 'saved_model.pth')
+                        torch.save(target.state_dict(), _save_path)
                         pass
                     except:
                         print('model cannot be saved, please check format')
 
+            import os
+            import zipfile
+
+            def zipdir(path, ziph):
+                # ziph is zipfile handle
+                for root, dirs, files in os.walk(path):
+                    for file in files:
+                        ziph.write(os.path.join(root, file),
+                                   os.path.relpath(os.path.join(root, file),
+                                                   os.path.join(path, '..')))
+            zip_name = str(epoch_time) + '.zip'
+            with zipfile.ZipFile(zip_name, 'w', zipfile.ZIP_DEFLATED) as zipf:
+                zipdir(_path, zipf)
+
         if self.remote_path:
             tp = int(time.time())
             json_struct = {"metadata": self.metadata, "best": [
